Crate uv_preview

Crate uv_preview 

Structs

EmptyPreviewFeatureNameError
Preview
PreviewFeatureParseError

Enums

MaybePreviewFeature
A user-provided preview feature name, which may refer to an unknown feature.
PreviewError
Error type for global preview state initialization related errors
PreviewFeature

Functions

finalize
is_enabled
Check if a specific preview feature is enabled globally.
set
Initialize the global preview configuration.