pub fn set(preview: Preview) -> Result<(), PreviewError>Expand description
Initialize the global preview configuration.
This should be called once at startup with the resolved preview settings.
pub fn set(preview: Preview) -> Result<(), PreviewError>Initialize the global preview configuration.
This should be called once at startup with the resolved preview settings.