Structs
Enums
- Maybe
Preview Feature - A user-provided preview feature name, which may refer to an unknown feature.
- Preview
Error - Error type for global preview state initialization related errors
- Preview
Feature
Functions
- finalize
- is_
enabled - Check if a specific preview feature is enabled globally.
- set
- Initialize the global preview configuration.