Crate uv_preview

Crate uv_preview 

Structs

Preview
PreviewFeatureParseError

Enums

PreviewError
Error type for global preview state initialization related errors
PreviewFeature
PreviewParseError

Functions

finalize
get
Get the current global preview configuration.
is_enabled
Check if a specific preview feature is enabled globally.
set
Initialize the global preview configuration.