Structs
- Preview
- Preview
Feature Parse Error - SetError
- Error returned when
finalizeis called on an uninitialized state.
Enums
- Preview
Error - Error type for global preview state initialization related errors
- Preview
Feature - Preview
Parse Error
Functions
- finalize
- get
- Get the current global preview configuration.
- is_
enabled - Check if a specific preview feature is enabled globally.
- set
- Initialize the global preview configuration.